qlog

package
v0.0.0-...-4155a33 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 26, 2020 License: MIT Imports: 9 Imported by: 8

Documentation

Index

Constants

const (
	Ldate         = 1 << iota     // the date in the local time zone: 2009/01/23
	Ltime                         // the time in the local time zone: 01:23:23
	Lmicroseconds                 // microsecond resolution: 01:23:23.123123.  assumes Ltime.
	Llongfile                     // full file name and line number: /a/b/c/d.go:23
	Lshortfile                    // final file name element and line number: d.go:23. overrides Llongfile
	LUTC                          // if Ldate or Ltime is set, use UTC rather than the local time zone
	LstdFlags     = Ldate | Ltime // initial values for the standard logger
)

These flags define which text to prefix to each log entry generated by the Logger. Bits are or'ed together to control what's printed. There is no control over the order they appear (the order listed here) or the format they present (as described in the comments). The prefix is followed by a colon only when Llongfile or Lshortfile is specified. For example, flags Ldate | Ltime (or LstdFlags) produce,

2009/01/23 01:23:23 message

while flags Ldate | Ltime | Lmicroseconds | Llongfile produce,

2009/01/23 01:23:23.123123 /a/b/c/d.go:23: message
const CODEINFO = 1000
const DEBUG = 1
const ERROR = 4
const FATAL = 5
const INFO = 2
const TRACE = 100
const VERBOSE = 0
const WARN = 3

Variables

var LEVELSTRS = [6]string{"VERBOSE", "DEBUG", "INFO", "WARN", "ERROR", "FATAL"}

Functions

func Error

func Error(stackSkip int, v ...interface{})

func Fatal

func Fatal(v ...interface{})

Fatal is equivalent to Print() followed by a call to os.Exit(1).

func Fatalf

func Fatalf(format string, v ...interface{})

Fatalf is equivalent to Printf() followed by a call to os.Exit(1).

func Fatalln

func Fatalln(v ...interface{})

Fatalln is equivalent to Println() followed by a call to os.Exit(1).

func Flags

func Flags() int

Flags returns the output flags for the standard logger.

func LevelInt

func LevelInt(level string) int

func LevelStr

func LevelStr(level int) string

func Log

func Log(level int, v ...interface{})

func LogEx

func LogEx(level int, stackSkip int, v ...interface{})

func Output

func Output(calldepth int, s string) error

Output writes the output for a logging event. The string s contains the text to print after the prefix specified by the flags of the Logger. A newline is appended if the last character of s is not already a newline. Calldepth is the count of the number of frames to skip when computing the file name and line number if Llongfile or Lshortfile is set; a value of 1 will print the details for the caller of Output.

func Panic

func Panic(v ...interface{})

Panic is equivalent to Print() followed by a call to panic().

func Panicf

func Panicf(format string, v ...interface{})

Panicf is equivalent to Printf() followed by a call to panic().

func Panicln

func Panicln(v ...interface{})

Panicln is equivalent to Println() followed by a call to panic().

func Prefix

func Prefix() string

Prefix returns the output prefix for the standard logger.

func Print

func Print(v ...interface{})

Print calls Output to print to the standard logger. Arguments are handled in the manner of fmt.Print.

func Printf

func Printf(format string, v ...interface{})

Printf calls Output to print to the standard logger. Arguments are handled in the manner of fmt.Printf.

func Println

func Println(v ...interface{})

Println calls Output to print to the standard logger. Arguments are handled in the manner of fmt.Println.

func SetFlags

func SetFlags(flag int)

SetFlags sets the output flags for the standard logger.

func SetOutput

func SetOutput(w io.Writer)

SetOutput sets the output destination for the standard logger.

func SetPrefix

func SetPrefix(prefix string)

SetPrefix sets the output prefix for the standard logger.

Types

type LogManager

type LogManager struct {
	// contains filtered or unexported fields
}

func GetLogManager

func GetLogManager() *LogManager

func (*LogManager) Get

func (o *LogManager) Get(key string) *Logi

func (*LogManager) GetDef

func (o *LogManager) GetDef() *Logi

func (*LogManager) LevelInt

func (o *LogManager) LevelInt(level string) int

func (*LogManager) LevelStr

func (o *LogManager) LevelStr(level int) string

func (*LogManager) New

func (o *LogManager) New(key string, dir string, prefix string, suffix string, level string, stdout bool, logflag int) *Logi

func (*LogManager) Set

func (o *LogManager) Set(key string, logi *Logi)

func (*LogManager) SetDef

func (o *LogManager) SetDef(dir, suffix string, level int, stdout bool, flag int) *Logi

type Logger

type Logger struct {
	// contains filtered or unexported fields
}

A Logger represents an active logging object that generates lines of output to an io.Writer. Each logging operation makes a single call to the Writer's Write method. A Logger can be used simultaneously from multiple goroutines; it guarantees to serialize access to the Writer.

func New

func New(out io.Writer, prefix string, flag int) *Logger

New creates a new Logger. The out variable sets the destination to which log data will be written. The prefix appears at the beginning of each generated log line. The flag argument defines the logging properties.

func (*Logger) Fatal

func (l *Logger) Fatal(v ...interface{})

Fatal is equivalent to l.Print() followed by a call to os.Exit(1).

func (*Logger) Fatalf

func (l *Logger) Fatalf(format string, v ...interface{})

Fatalf is equivalent to l.Printf() followed by a call to os.Exit(1).

func (*Logger) Fatalln

func (l *Logger) Fatalln(v ...interface{})

Fatalln is equivalent to l.Println() followed by a call to os.Exit(1).

func (*Logger) Flags

func (l *Logger) Flags() int

Flags returns the output flags for the logger.

func (*Logger) Output

func (l *Logger) Output(calldepth int, s string) error

Output writes the output for a logging event. The string s contains the text to print after the prefix specified by the flags of the Logger. A newline is appended if the last character of s is not already a newline. Calldepth is used to recover the PC and is provided for generality, although at the moment on all pre-defined paths it will be 2.

func (*Logger) Panic

func (l *Logger) Panic(v ...interface{})

Panic is equivalent to l.Print() followed by a call to panic().

func (*Logger) Panicf

func (l *Logger) Panicf(format string, v ...interface{})

Panicf is equivalent to l.Printf() followed by a call to panic().

func (*Logger) Panicln

func (l *Logger) Panicln(v ...interface{})

Panicln is equivalent to l.Println() followed by a call to panic().

func (*Logger) Prefix

func (l *Logger) Prefix() string

Prefix returns the output prefix for the logger.

func (*Logger) Print

func (l *Logger) Print(v ...interface{})

Print calls l.Output to print to the logger. Arguments are handled in the manner of fmt.Print.

func (*Logger) Printf

func (l *Logger) Printf(format string, v ...interface{})

Printf calls l.Output to print to the logger. Arguments are handled in the manner of fmt.Printf.

func (*Logger) Println

func (l *Logger) Println(v ...interface{})

Println calls l.Output to print to the logger. Arguments are handled in the manner of fmt.Println.

func (*Logger) SetFlags

func (l *Logger) SetFlags(flag int)

SetFlags sets the output flags for the logger.

func (*Logger) SetOutput

func (l *Logger) SetOutput(w io.Writer)

SetOutput sets the output destination for the logger.

func (*Logger) SetPrefix

func (l *Logger) SetPrefix(prefix string)

SetPrefix sets the output prefix for the logger.

func (*Logger) Writer

func (l *Logger) Writer() io.Writer

Writer returns the output destination for the logger.

type Logi

type Logi struct {
	Dir        string
	Level      int
	ToStdout   bool
	LogFlag    int
	LogPrefix  string
	FilePrefix string
	FileSuffix string
	// contains filtered or unexported fields
}

func (*Logi) AddWriter

func (o *Logi) AddWriter(writer io.Writer, prefix string, flag int, lock bool)

func (*Logi) Debug

func (o *Logi) Debug(v ...interface{})

func (*Logi) Destroy

func (o *Logi) Destroy(lock bool)

func (*Logi) Error

func (o *Logi) Error(skipStack int, v ...interface{})

func (*Logi) Fatal

func (o *Logi) Fatal(skipStack int, v ...interface{})

func (*Logi) Info

func (o *Logi) Info(v ...interface{})

func (*Logi) InitWriter

func (o *Logi) InitWriter(today *time.Time)

func (*Logi) Log

func (o *Logi) Log(level int, v ...interface{})

func (*Logi) LogEx

func (o *Logi) LogEx(level int, stackSkip int, v ...interface{})

func (*Logi) Print

func (o *Logi) Print(line string, stackstr string)

func (*Logi) Printf

func (o *Logi) Printf(format string, v ...interface{})

func (*Logi) SetWriters

func (o *Logi) SetWriters(writers []io.Writer)

func (*Logi) Verbose

func (o *Logi) Verbose(v ...interface{})

func (*Logi) Warn

func (o *Logi) Warn(v ...interface{})

Jump to